@@ -3,13 +3,13 @@ import os
 import shutil
 import tempfile
 
+import pytest
+
 from docker import errors
 from docker.utils.proxy import ProxyConfig
 
-import pytest
-
-from .base import BaseAPIIntegrationTest, TEST_IMG
 from ..helpers import random_name, requires_api_version, requires_experimental
+from .base import TEST_IMG, BaseAPIIntegrationTest
 
 
 class BuildTest(BaseAPIIntegrationTest):
@@ -389,9 +389,7 @@ class BuildTest(BaseAPIIntegrationTest):
         lines = []
         for chunk in stream:
             lines.append(chunk.get('stream'))
-        expected = '{0}{2}\n{1}'.format(
-            control_chars[0], control_chars[1], snippet
-        )
+        expected = f'{control_chars[0]}{snippet}\n{control_chars[1]}'
         assert any(line == expected for line in lines)
 
     def test_build_gzip_encoding(self):
